## Description

Brief description of the changes in this PR.

## Related Issue

Fixes #(issue number)

## Type of Change

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)

## Changes Made

- Change 1
- Change 2
- Change 3

## Testing

- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] I have run `pytest tests/ -v` and all tests pass

## Code Quality

- [ ] My code follows the style guidelines of this project
- [ ] I have run `ruff check src/` with no errors
- [ ] I have run `mypy src/` with no errors
- [ ] I have added docstrings to new public functions/classes

## Documentation

- [ ] I have updated the README if needed
- [ ] I have updated the CHANGELOG if needed
- [ ] My changes require no documentation updates

## Screenshots (if applicable)

Add any relevant screenshots here.
